.. Punq documentation master file, created by
   sphinx-quickstart on Tue Feb  5 18:19:18 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Punq's documentation!
================================

.. contents:
.. include:: ../../README.rst

API
---

.. autoclass:: punq.Container
    :members:
    :member-order: bysouce

.. autoexception:: punq.MissingDependencyException
    :members:
    :member-order: bysouce

.. autoexception:: punq.InvalidRegistrationException
    :members:
    :member-order: bysouce


.. autoexception:: punq.InvalidForwardReferenceException
    :members:
    :member-order: bysouce
